@@ -21,7 +21,7 @@ try:
     # Python 3
     import urllib.parse as urlparse
     from urllib.parse import urlencode
-    import reprlib 
+    import reprlib
     string_types = (str, bytes)
 except ImportError:
     # Python 2
@@ -38,15 +38,24 @@ except ImportError:
     WebobBaseRequest = None
 
 try:
-    from django.http import HttpRequest as DjangoHttpRequest
+    from django.core.exceptions import ImproperlyConfigured
 except ImportError:
     DjangoHttpRequest = None
-
-try:
-    from rest_framework.request import Request as RestFrameworkRequest
-except ImportError:
     RestFrameworkRequest = None
 
+else:
+    try:
+        from django.http import HttpRequest as DjangoHttpRequest
+    except (ImportError, ImproperlyConfigured):
+        DjangoHttpRequest = None
+
+    try:
+        from rest_framework.request import Request as RestFrameworkRequest
+    except (ImportError, ImproperlyConfigured):
+        RestFrameworkRequest = None
+
+    del ImproperlyConfigured
+
 try:
     from werkzeug.wrappers import Request as WerkzeugRequest
 except ImportError:
@@ -118,7 +127,7 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.8.1'
+VERSION = '0.8.2'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
@@ -813,7 +822,7 @@ def _in_scrub_fields(val, scrub_fields):
             return True
 
     return False
-        
+
 
 def _local_repr(obj):
     orig = repr(obj)
